@@ -7,13 +7,11 @@
 #include <glib-object.h>
 
 G_BEGIN_DECLS
-/* enumerations from "./bacon-video-widget.h" */
+/* enumerations from "/home/hadess/Projects/jhbuild/totem-tmp/src/backend/bacon-video-widget.h" */
 GType bvw_error_get_type (void) G_GNUC_CONST;
 #define BVW_TYPE_ERROR (bvw_error_get_type())
 GType bvw_metadata_type_get_type (void) G_GNUC_CONST;
 #define BVW_TYPE_METADATA_TYPE (bvw_metadata_type_get_type())
-GType bvw_visualization_quality_get_type (void) G_GNUC_CONST;
-#define BVW_TYPE_VISUALIZATION_QUALITY (bvw_visualization_quality_get_type())
 GType bvw_video_property_get_type (void) G_GNUC_CONST;
 #define BVW_TYPE_VIDEO_PROPERTY (bvw_video_property_get_type())
 GType bvw_aspect_ratio_get_type (void) G_GNUC_CONST;
